@@ -1,4 +1,5 @@
 import pandas as _pd
+import re as _re
 
 
 def csv_files_2_df(
@@ -64,6 +65,18 @@ def csv_files_2_df(
 
     df_concat = _pd.concat(l_df, axis=0, ignore_index=True)
     __set_df_col_dtypes(df_concat)
+
+    # if view-id=0 similuate attrib view col
+    if "viewchannel_lvl_p0" not in df_concat.columns:
+        for col_name in df_concat:
+            if col_name.startswith("channel_lvl0_"):
+                newcol_name = _re.sub(
+                    pattern=r"^channel_lvl0_(.+)$",
+                    repl=r"viewchannel_\g<1>",
+                    string=col_name
+                )
+                df_concat[newcol_name] = df_concat[col_name]
+
     return df_concat
 
 def __set_df_col_dtypes( df : _pd.DataFrame() ):
